@@ -3,6 +3,9 @@ import os
 from .db import delete, draw,fetch
 from .db import insert as insert_data
 
+import pathlib
+pathlib.Path(__file__).parent.resolve()
+
 # draw the database 
 draw()
 
@@ -11,6 +14,7 @@ print("-"*20,"\n")
 app = typer.Typer()
 
 
+
 @app.command()
 def insert(name,path):
     insert_data(name,path)
@@ -39,5 +43,6 @@ def remove(name):
 
 
 
+
 if __name__ == '__main__':
     app()
\ No newline at end of file
